@@ -1,4 +1,5 @@
 from .apk_scanner import startScan
+from .apk_decompiling import decompiling
 from .cli import run
 from .result_wirter import *
 
@@ -6,5 +7,6 @@ __all__ = (
     'run',
     'startScan',
     'ResultWirter',
+    'decompiling',
 )
 
