@@ -1,15 +1,15 @@
 import os
-import sys
 import zipfile
 import shutil
 import subprocess
+from skyeye.utils import *
 
 def decompiling(apkPath:str,resultDir):
     if not os.path.exists(apkPath):
         print("❌apk文件不存在:"+apkPath)
         return
     if not zipfile.is_zipfile(apkPath):
-        print("❌apk文件错误:"+apkPath)
+        print("❌apk文件类型错误:"+apkPath)
         return   
     #将APK 改为zip 解压到resultDir目录
     realApkPath = os.path.join(os.getcwd(),apkPath)
@@ -36,23 +36,26 @@ def decompiling(apkPath:str,resultDir):
             unzipJar(jarPath,outputDirPath)
             #删除jar
             delFiles(jarPath)
+    print("✅反编译目录->"+outputDirPath)
     openGUI(outputDirPath)
- 
- 
-
     
 def openGUI(outputDirPath):
-    walk = os.walk(outputDirPath)
     firstClassFilePath = ""
-    for path,dir_list,file_list in walk:
-        for file_name in file_list:
-            if file_name.endswith(".class") and  len(firstClassFilePath)==0:
-               firstClassFilePath = os.path.join(path,file_name)  
-    print("✅正在打开JD-GUI firstClass->"+firstClassFilePath)
+    if(not isEmpty(outputDirPath)):
+        walk = os.walk(outputDirPath)
+        for path,dir_list,file_list in walk:
+            for file_name in file_list:
+                if file_name.endswith(".class") and  len(firstClassFilePath)==0:
+                    firstClassFilePath = os.path.join(path,file_name)
     current_file_dir = os.path.dirname(__file__)
     guiPath=  os.path.join(current_file_dir,'config/jd-gui-1.6.6.jar')
-    command ="java -jar "+guiPath+ " " +firstClassFilePath
-    # os.popen(command)
+    command = None
+    if(isEmpty(firstClassFilePath)):
+        command ="java -jar "+guiPath
+        print("✅正在打开JD-GUI") 
+    else:
+        print("✅正在打开JD-GUI firstClass->"+firstClassFilePath) 
+        command ="java -jar "+guiPath+ " " +firstClassFilePath
     subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     
 def unzipJar(jarPath,outputDirPath):
@@ -76,7 +79,7 @@ def dex2Jar(dexPath):
     
 def delFiles(filePath):
     if os.path.exists(filePath):
-       print("🧹正在删除->"+filePath)
+       #print("🧹正在删除->"+filePath)
        if os.path.isdir(filePath):
            shutil.rmtree(filePath)
        else:
